@@ -173,7 +173,7 @@ INVALIDPARAMETER_BATCHRECORDREMOVEACTIONERROR = 'InvalidParameter.BatchRecordRem
 # 批量替换记录任务失败，原因：内部错误。
 INVALIDPARAMETER_BATCHRECORDREPLACEACTIONERROR = 'InvalidParameter.BatchRecordReplaceActionError'
 
-# 超过批量任务数上限。
+# 超过单个账号的批量任务数并发上限4个。
 INVALIDPARAMETER_BATCHTASKCOUNTLIMIT = 'InvalidParameter.BatchTaskCountLimit'
 
 # 任务不存在，无法获取任务详情。
@@ -188,6 +188,9 @@ INVALIDPARAMETER_BROWSERNULL = 'InvalidParameter.BrowserNull'
 # 您操作过于频繁，请稍后重试。
 INVALIDPARAMETER_COMMON = 'InvalidParameter.Common'
 
+# 您复制的线路已存在，无需重复复制。
+INVALIDPARAMETER_COPIEDLINEGROUPDUPLICATED = 'InvalidParameter.CopiedLineGroupDuplicated'
+
 # 自定义错误信息。
 INVALIDPARAMETER_CUSTOMMESSAGE = 'InvalidParameter.CustomMessage'
 
@@ -200,6 +203,9 @@ INVALIDPARAMETER_DATAINVALID = 'InvalidParameter.DataInvalid'
 # 订单类型无效。
 INVALIDPARAMETER_DEALTYPEINVALID = 'InvalidParameter.DealTypeInvalid'
 
+# 默认线路无法进行自定义线路分组。
+INVALIDPARAMETER_DEFAULTLINENOTSELFDEFINED = 'InvalidParameter.DefaultLineNotSelfdefined'
+
 # 域名已升级至付费套餐，无法完成下单。
 INVALIDPARAMETER_DNSDEALDOMAINUPGRADED = 'InvalidParameter.DnsDealDomainUpgraded'
 
@@ -299,12 +305,18 @@ INVALIDPARAMETER_GRADENOTCOPY = 'InvalidParameter.GradeNotCopy'
 # 分组编号不正确。
 INVALIDPARAMETER_GROUPIDINVALID = 'InvalidParameter.GroupIdInvalid'
 
+# 分组名为空。
+INVALIDPARAMETER_GROUPNAMEEMPTY = 'InvalidParameter.GroupNameEmpty'
+
 # 同名分组已经存在。
 INVALIDPARAMETER_GROUPNAMEEXISTS = 'InvalidParameter.GroupNameExists'
 
 # 分组名为1-17个字符。
 INVALIDPARAMETER_GROUPNAMEINVALID = 'InvalidParameter.GroupNameInvalid'
 
+# 指定的分组名已存在，或为系统内置线路或自定义线路，无法用于分组名称。
+INVALIDPARAMETER_GROUPNAMEOCCUPIED = 'InvalidParameter.GroupNameOccupied'
+
 # 您已经提交过申请并且正在审核中，请耐心等候。
 INVALIDPARAMETER_HASPENDINGAPPLY = 'InvalidParameter.HasPendingApply'
 
@@ -329,6 +341,9 @@ INVALIDPARAMETER_INVALIDSECRETID = 'InvalidParameter.InvalidSecretId'
 # 无效签名。
 INVALIDPARAMETER_INVALIDSIGNATURE = 'InvalidParameter.InvalidSignature'
 
+# 源域名ID格式不正确。
+INVALIDPARAMETER_INVALIDSRCDOMAINID = 'InvalidParameter.InvalidSrcDomainId'
+
 # 无效的时间。
 INVALIDPARAMETER_INVALIDTIME = 'InvalidParameter.InvalidTime'
 
@@ -344,12 +359,30 @@ INVALIDPARAMETER_IPAREA = 'InvalidParameter.IpArea'
 # ips 过长。
 INVALIDPARAMETER_IPSEXCEEDLIMIT = 'InvalidParameter.IpsExceedLimit'
 
-# 单次任务数量超过上限。
+# 单次任务记录数量超过上限5000条。
 INVALIDPARAMETER_JOBGREATERTHANLIMIT = 'InvalidParameter.JobGreaterThanLimit'
 
+# 线路格式不正确。
+INVALIDPARAMETER_LINEFORMATINVALID = 'InvalidParameter.LineFormatInvalid'
+
+# 线路不存在，或者线路不支持自定义分组。
+INVALIDPARAMETER_LINEGROUPNOTSUPPORTED = 'InvalidParameter.LineGroupNotSupported'
+
+# 当前套餐的线路分组已达到数量上限。
+INVALIDPARAMETER_LINEGROUPOVERCOUNTED = 'InvalidParameter.LineGroupOverCounted'
+
+# 线路分组更新失败，原因：内部错误。
+INVALIDPARAMETER_LINEGROUPUPDATEFAILED = 'InvalidParameter.LineGroupUpdateFailed'
+
+# 线路已存在于其他分组中。
+INVALIDPARAMETER_LINEINANOTHERGROUP = 'InvalidParameter.LineInAnotherGroup'
+
 # 线路正在使用当中，无法修改名称。
 INVALIDPARAMETER_LINEINUSE = 'InvalidParameter.LineInUse'
 
+# 线路正在使用当中，无法删除名称。
+INVALIDPARAMETER_LINEINUSENOTDELETE = 'InvalidParameter.LineInUseNotDelete'
+
 # 线路名称的长度不能超过17个字符。
 INVALIDPARAMETER_LINENAMEINVALID = 'InvalidParameter.LineNameInvalid'
 
@@ -359,6 +392,15 @@ INVALIDPARAMETER_LINENAMEINVALIDCHARACTER = 'InvalidParameter.LineNameInvalidCha
 # 线路名是系统内置线路或用户自定义分组线路，无法使用该名称。
 INVALIDPARAMETER_LINENAMEOCCUPIED = 'InvalidParameter.LineNameOccupied'
 
+# 分组不存在，请确认是否已经被删除了。
+INVALIDPARAMETER_LINENOTEXIST = 'InvalidParameter.LineNotExist'
+
+# 您至少需要选择一个线路。
+INVALIDPARAMETER_LINENOTSELECTED = 'InvalidParameter.LineNotSelected'
+
+# 最多只能选择120个线路。
+INVALIDPARAMETER_LINEOVERCOUNTED = 'InvalidParameter.LineOverCounted'
+
 # 锁定天数不正确。
 INVALIDPARAMETER_LOCKDAYSINVALID = 'InvalidParameter.LockDaysInvalid'
 
@@ -380,6 +422,12 @@ INVALIDPARAMETER_MXINVALID = 'InvalidParameter.MxInvalid'
 # 新套餐类型无效。
 INVALIDPARAMETER_NEWPACKAGETYPEINVALID = 'InvalidParameter.NewPackageTypeInvalid'
 
+# 您不是源域名所有者，无法复制线路。
+INVALIDPARAMETER_NOAUTHORITYTOSRCDOMAIN = 'InvalidParameter.NoAuthorityToSrcDomain'
+
+# 分组不属于当前域名，请确认您是否有权限修改分组。
+INVALIDPARAMETER_NOAUTHORITYTOTHEGROUP = 'InvalidParameter.NoAuthorityToTheGroup'
+
 # 分页起始数量错误。
 INVALIDPARAMETER_OFFSETINVALID = 'InvalidParameter.OffsetInvalid'
 
@@ -644,7 +692,7 @@ OPERATIONDENIED_VIPDOMAINALLOWED = 'OperationDenied.VipDomainAllowed'
 # 请求的次数超过了频率限制。
 REQUESTLIMITEXCEEDED = 'RequestLimitExceeded'
 
-# 您的IP添加了过多任务，请稍后重试。
+# 您的IP添加了过多任务。每个小时内，一个IP最多可提交80个任务，请稍后重试。
 REQUESTLIMITEXCEEDED_BATCHTASKLIMIT = 'RequestLimitExceeded.BatchTaskLimit'
 
 # 您的账号在短时间内添加了大量的域名，请控制添加频率。
